```javascript
import logging from 'improved-logging'

logging.info('This is logging example')
```

This is a node.js module for logging

# Usage:

## Log types
```javascript
import logging from 'improved-logging'

logging.info('Some information')
logging.important('Some important information')
logging.success('Something is done')
logging.warn('Warning')
logging.error('Something went wrong')
logging.fatal('Critical error')
```

## if you want to log all also in file
```javascript
const loggingDir = path.join(__dirname, '../', 'logs')
logging.setLogDir(loggingDir)
logging.setLogfileName(path.join(loggingDir, 'main.log'))

logging.info('Now will log all to file')
```

## if you want to watch all logs from browser (it could be helpful when you do automatization)
```javascript
import logging, { getLoggingRouter } from 'improved-logging'
import enableWs from 'express-ws'
import express from 'express'
import http from 'http'

const PORT = 3000,
      HOST = '192.168.0.171',
      LOGGING_ROUTE_NAME = '/logging'

const appExpress = express()
const app = enableWs(appExpress).app
const server = http.createServer(app);

const loggingRouter = getLoggingRouter(HOST, PORT, LOGGING_ROUTE_NAME)

app.use(loggingRouter)

app.listen(PORT, () => logging.success(`Server is running on port ${PORT}`))

setInterval(() => {
    const randomFrom0To100 = Math.floor(Math.random() * 100)
    logging.info('Its just a random number for you to make shure that everything is working: '+ randomFrom0To100)
}, 600)

```

## You can use verbose logs and turn different logs on/off
```javascript
logging.verbose('You will see it in console')

logging.setLogLevel('success')

logging.verbose('That one is hidden')


logging.setLogLevel('imoprtant')

logging.important('Now info, success, verbose logs are hidden')
logging.info('You will not see it in console/log file/browser')
```
