import { SingleLog } from "./html/components/index.js";
export function logTypeToColor(type) {
    if (type === 'fatal')
        return '#ff0000';
    if (type === 'error')
        return '#af1f1f';
    if (type === 'warn')
        return '#b0bb15';
    if (type === 'important')
        return '#1406df';
    if (type === 'info')
        return '#4235f0';
    if (type === 'success')
        return '#028a2b';
    if (type === 'verbose')
        return '#8c8c8c';
    return '#000000';
}
function getLoggingType(type) {
    if (type === 'verbose')
        return '[ VERBOSE ]';
    if (type === 'success')
        return '[ SUCCESS ]';
    if (type === 'important')
        return '[ IMPORTANT ]';
    if (type === 'info')
        return '[ INFO ]';
    if (type === 'warn')
        return '[ WARN ]';
    if (type === 'error')
        return '[ ERROR ]';
    if (type === 'fatal')
        return '[ FATAL ]';
    return '[ UNKNOWN LOGGING TYPE ]';
}
/**
 * @param timestamp time when log added
 * @returns {string} format: "month/day/year | hours:minutes:seconds AM||PM"
 * @example '8/9/2022 | 2:12:03 AM'
 */
function timestampToDate(timestamp) {
    const currentDate = new Date(timestamp);
    const date = currentDate.toLocaleDateString('en-US');
    const time = currentDate.toLocaleTimeString('en-US');
    return `${date} | ${time}`;
}
export function getSingleLog(type, date, text) {
    return SingleLog(getLoggingType(type), logTypeToColor(type), timestampToDate(date), text);
}
export function generateHTML(logging, host, port) {
    const divs = logging.reduce((accamulator, log) => {
        const { type, date, text } = log;
        return accamulator + getSingleLog(type, date, text);
    }, '');
    const htmlContent = `
        <html>
            <head>
            <script>
            function script() {
                if (document.body.offsetWidth < 1000) document.querySelector('body').style.fontSize = '32px'
            
                const ws = new WebSocket('ws://${host}:${port}/logging')
                ws.onmessage = (msg) => {
                    console.log(msg.data)
                    const parsed = JSON.parse(msg.data)
                    document.querySelector('body').insertAdjacentHTML('beforeend', parsed.newLog)
                    window.scrollTo(0,document.body.scrollHeight);
                }
            }
            </script>
            </head>
            <body onload="script();" style="
                font-size: 16px;
                margin: 5px;
            ">
                ${divs}
            </body>
        </html>
    `;
    return htmlContent;
}
