import fs from 'fs';
import path from 'path';
import { loggingLocal } from './router.js';
import { getSingleLog } from './routerUtils.js';
import { colors } from './colors.js';
import { WebServerLogging } from './weblogging.js';
let sendNewLogToClient = function (props) { };
const loggingValues = {
    fatal: 0,
    error: 1,
    warn: 2,
    important: 3,
    success: 4,
    info: 5,
    verbose: 6
};
export function getColoredText(text, color = 'black', ...notColoredTexts) {
    // const colors: { [key in Tcolor]: ChalkInstance } = {
    const coloredText = colors[color](text) + notColoredTexts;
    return coloredText;
}
/**
* @param {String} text text to return
* @param {*} color enums: [black, red, green, yellow, blue, magenta, cyan, white]
* @returns colored text
*/
function coloredConsoleLog(text, color = 'black', ...notColoredTexts) {
    const coloredText = getColoredText(text, color, ...notColoredTexts);
    console.log(coloredText);
}
class OurLogging extends WebServerLogging {
    loggingBrowserLength;
    historyLogsLength;
    #logLevel = 6;
    #logFileName;
    constructor(historyLogsLength) {
        super();
        const defaultLength = 100;
        this.loggingBrowserLength = 80;
        this.historyLogsLength = historyLogsLength || defaultLength;
    }
    setLogLevel(newLevel) { this.#logLevel = loggingValues[newLevel]; }
    setBrowserMessagesAmount(amount) { this.loggingBrowserLength = amount; }
    setLogfileName(name) { this.#logFileName = name; }
    fatal(text, stackTrace = '') {
        if (!this.#aboveSelectedLogLevel('fatal'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ FATAL ERROR ] ${currentTime} | ${text}  ${stackTrace}`;
        coloredConsoleLog('[ FATAL ERROR ] ', 'carmine', `${currentTime} | ${text} ${stackTrace}`);
        this.#addLogToGlobal(text + ' ' + stackTrace, 'fatal');
        this.#logTextToFile(logText);
    }
    error(text, stackTrace = '') {
        if (!this.#aboveSelectedLogLevel('error'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ ERROR ] ${currentTime} | ${text} ${stackTrace}`;
        coloredConsoleLog('[ ERROR ] ', 'scarlet', `${currentTime} | ${text} ${stackTrace}`);
        this.#addLogToGlobal(text + ' ' + stackTrace, 'error');
        this.#logTextToFile(logText);
    }
    warn(...text) {
        if (!this.#aboveSelectedLogLevel('warn'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ WARNING ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ WARNING ] ', 'yellow', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text.join(' '), 'warn');
        this.#logTextToFile(logText);
    }
    important(...text) {
        if (!this.#aboveSelectedLogLevel('important'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ IMPORTANT ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ IMPORTANT ] ', 'blue', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text.join(' '), 'info');
        this.#logTextToFile(logText);
    }
    info(...text) {
        if (!this.#aboveSelectedLogLevel('info'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ INFO ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ INFO ] ', 'lightblue', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text.join(' '), 'info');
        this.#logTextToFile(logText);
    }
    verbose(...text) {
        if (!this.#aboveSelectedLogLevel('verbose'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ VERBOSE ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ VERBOSE ] ', 'verbose_color', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text.join(' '), 'verbose');
        this.#logTextToFile(logText);
    }
    success(...text) {
        if (!this.#aboveSelectedLogLevel('success'))
            return;
        const currentTime = this.#getDateTime();
        let logText = `\n[ SUCCESS ] ${currentTime} | ${text}`;
        coloredConsoleLog('[ SUCCESS ] ', 'green', `${currentTime} | ${text}`);
        this.#addLogToGlobal(text.join(' '), 'success');
        this.#logTextToFile(logText);
    }
    #addLogToGlobal(text, type) {
        if (loggingLocal.length > this.loggingBrowserLength)
            loggingLocal.shift();
        loggingLocal.push({ text, type, date: new Date().getTime() });
        sendNewLogToClient({ text, type, date: new Date().getTime() });
    }
    #getDateTime() {
        var currentDate = new Date();
        const date = currentDate.toLocaleDateString('en-US');
        const time = currentDate.toLocaleTimeString('en-US');
        return `${date} | ${time}`;
    }
    #logTextToFile(logText) {
        if (!this.#logFileName)
            return;
        if (!fs.existsSync(this.#logFileName)) {
            const dirname = path.dirname(this.#logFileName);
            fs.mkdirSync(dirname, { recursive: true });
        }
        try {
            fs.appendFileSync(this.#logFileName, logText);
        }
        catch (error) {
            console.error(coloredConsoleLog('LOGGING ERROR: ', 'scarlet', error.message));
        }
    }
    #aboveSelectedLogLevel(testedLogLevel) {
        const selectedLogLevel = this.#logLevel;
        const wantedLogLevel = loggingValues[testedLogLevel];
        return wantedLogLevel <= selectedLogLevel;
    }
}
const logging = new OurLogging();
export default logging;
export * from './router.js';
export const loggingWS = (ws) => {
    sendNewLogToClient = function (props) {
        ws.send(JSON.stringify({
            newLog: getSingleLog(props.type, props.date, props.text)
        }));
    };
};
