import express, { Router, Request, Response } from 'express';
import logging, { getColoredText, loggingWS, Tlogging } from './general.js';
import expressWs from 'express-ws';
import * as loggingUtils from './routerUtils.js'
import chalk from 'chalk';

export const loggingLocal: TloggingLocal = []
export type Tlog = { text: string, type: Tlogging, date: number }
export type TloggingLocal = Tlog[]

const enableWSExample = () => {
    const magenta = (text: string) => chalk.hex('#ff70ff')(text)
    const cyan = (text: string) => chalk.hex('#6bc4ff')(text)
    const brown = (text: string) => chalk.hex('#ad6744')(text)
    const lightblue = (text: string) => chalk.hex('#2461c9')(text)
    const blue = (text: string) => chalk.hex('#0a44a8')(text)
    const yellow = (text: string) => chalk.hex('#9da133')(text)
    return `
${magenta('import')} ${cyan('enableWS')} ${magenta('from')} ${brown("'express-ws'")}
${getColoredText('// some other code', 'green')}
${blue('const')} ${lightblue('app')} = ${yellow('express()')}
${yellow(`enableWS(${lightblue('app')})`)}`
}


export function getLoggingRouter(host: string, port: number, routeName: string) {
    const loggingRouter = Router()

    loggingRouter.get(routeName, (req: Request, res: Response) => {
        res.set('Content-Type', 'text/html')

        const html = loggingUtils.generateHTML(loggingLocal, host, port, routeName)

        res.end(html)
    })
    if (!loggingRouter.ws)
        logging.warn(`Messages will NOT update in browser automatically, please enable websocket for your express app\n`
            + `Enable ws: ${enableWSExample()}`)
    else
        loggingRouter.ws(routeName, loggingWS)

    return loggingRouter
}
