import { Router } from 'express';
import logging, { getColoredText, loggingWS } from './general.js';
import * as loggingUtils from './routerUtils.js';
import chalk from 'chalk';
export const loggingLocal = [];
const enableWSExample = () => {
    const magenta = (text) => chalk.hex('#ff70ff')(text);
    const cyan = (text) => chalk.hex('#6bc4ff')(text);
    const brown = (text) => chalk.hex('#ad6744')(text);
    const lightblue = (text) => chalk.hex('#2461c9')(text);
    const blue = (text) => chalk.hex('#0a44a8')(text);
    const yellow = (text) => chalk.hex('#9da133')(text);
    return `
${magenta('import')} ${cyan('enableWS')} ${magenta('from')} ${brown("'express-ws'")}
${getColoredText('// some other code', 'green')}
${blue('const')} ${lightblue('app')} = ${yellow('express()')}
${yellow(`enableWS(${lightblue('app')})`)}`;
};
export function getLoggingRouter(routeName) {
    const loggingRouter = Router();
    loggingRouter.get(routeName, (req, res) => {
        res.set('Content-Type', 'text/html');
        const html = loggingUtils.generateHTML(loggingLocal, routeName);
        res.end(html);
    });
    if (!loggingRouter.ws)
        logging.warn(`Messages will NOT update in browser automatically, please enable websocket for your express app\n`
            + `Enable ws: ${enableWSExample()}`);
    else
        loggingRouter.ws(routeName, loggingWS);
    return loggingRouter;
}
