import { TloggingLocal } from "./router.js"
import { Tlogging } from "./general"
import { SingleLog } from "./html/components/index.js"
import { colorsHex } from "./colors.js"

export function logTypeToColor(type: Tlogging): string {
    if (type === 'fatal')
        return colorsHex.carmine
    if (type === 'error')
        return colorsHex.scarlet
    if (type === 'warn')
        return colorsHex.yellow
    if (type === 'important')
        return colorsHex.blue
    if (type === 'info')
        return colorsHex.lightblue
    if (type === 'success')
        return colorsHex.green
    if (type === 'verbose')
        return colorsHex.verbose_color

    return colorsHex.black
}

function getLoggingType(type: Tlogging) {
    if (type === 'verbose')
        return '[ VERBOSE ]'
    if (type === 'success')
        return '[ SUCCESS ]'
    if (type === 'important')
        return '[ IMPORTANT ]'
    if (type === 'info')
        return '[ INFO ]'
    if (type === 'warn')
        return '[ WARN ]'
    if (type === 'error')
        return '[ ERROR ]'
    if (type === 'fatal')
        return '[ FATAL ]'

    return '[ UNKNOWN LOGGING TYPE ]'
}
/**
 * @param timestamp time when log added
 * @returns {string} format: "month/day/year | hours:minutes:seconds AM||PM"
 * @example '8/9/2022 | 2:12:03 AM'
 */
function timestampToDate(timestamp: number): string {
    const currentDate = new Date(timestamp)
    const date = currentDate.toLocaleDateString('en-US')
    const time = currentDate.toLocaleTimeString('en-US')
    return `${date} | ${time}`
}

export function getSingleLog(type: Tlogging, date: number, text: string) {
    return SingleLog(getLoggingType(type), logTypeToColor(type), timestampToDate(date), text)
}

export function generateHTML(logging: TloggingLocal, routeName: string) {
    const divs = logging.reduce((accamulator, log) => {
        const { type, date, text } = log
        return accamulator + getSingleLog(type, date, text)
    }, '')

    const htmlContent = `
        <html>
            <head>
            <link
    async
    rel="stylesheet"
    href="https://cdn.jsdelivr.net/npm/semantic-ui@2/dist/semantic.min.css"
  />
  <script src="https://cdn.jsdelivr.net/npm/semantic-ui-react/dist/umd/semantic-ui-react.min.js"></script>
            <style>
                body {margin: 0px;}
                div {margin: 0px; line-height: 1.4em;}
                button {
                    position: absolute ;
                    top: 50%;
                    left: 80%;
                }
            </style>
            <script>
            let shouldScroll = true
            function toggleScroll() {
                const newShouldScroll = document.querySelector('div').getAttribute("shouldScroll") === "true"
                console.log(newShouldScroll)
                shouldScroll = newShouldScroll
                if (newShouldScroll) {
                    document.querySelector('button').innerHTML = "stop scrolling"
                    document.querySelector('div').setAttribute("shouldScroll", "false")
                }
                else {
                    document.querySelector('button').innerHTML = "continue scrolling"
                    document.querySelector('div').setAttribute("shouldScroll", "true")
                }
            }
            function script() {
                if (document.body.offsetWidth < 1000) document.querySelector('body').style.fontSize = '32px'
            
                const host = window.location.host
                const ws = new WebSocket('ws://' + host + '${routeName}')
                ws.onmessage = (msg) => {
                    const parsed = JSON.parse(msg.data)
                    const loglist = document.querySelector('div')
                    loglist.insertAdjacentHTML('beforeend', parsed.newLog)
                    if (shouldScroll)
                        loglist.scrollTo(0, loglist.scrollHeight);
                }
            }
            </script>
            </head>
            <body onload="script();">
                <div shouldScroll="false" style="
                font-size: 16px;
                display: inline-block;
                padding: 8px;
                width: 70vw; height: 95vh;
                overflow-y: scroll;
            "> ${divs} </div>

                <div style="display: inline-block; width: 25vw">
                    <button class="ui button" onclick="toggleScroll()">
                        stop scrolling
                    </button>
                </div>
            </body>
        </html>
    `

    return htmlContent
}
